@@ -38,16 +38,12 @@ master_doc = 'index'
 project = u'Sahara Release Notes'
 copyright = u'2015, Sahara Developers'
 
-# The version info for the project you're documenting, acts as replacement for
-# |version| and |release|, also used in various other places throughout the
-# built documents.
-#
-# The short X.Y version.
-from sahara.version import version_info as sahara_version
+# Release do not need a version number in the title, they
+# cover multiple versions.
 # The full version, including alpha/beta/rc tags.
-release = sahara_version.version_string_with_vcs()
+release = ''
 # The short X.Y version.
-version = sahara_version.canonical_version_string()
+version = ''
 
 # List of patterns, relative to source directory, that match files and
 # directories to ignore when looking for source files.
