@@ -60,7 +60,7 @@ def clusters_create_multiple(data):
 @rest.put('/clusters/<cluster_id>')
 @acl.enforce("data-processing:clusters:scale")
 @v.check_exists(api.get_cluster, 'cluster_id')
-@v.validate(v_c_schema.CLUSTER_SCALING_SCHEMA, v_c_s.check_cluster_scaling)
+@v.validate(v_c_schema.CLUSTER_SCALING_SCHEMA_V2, v_c_s.check_cluster_scaling)
 def clusters_scale(cluster_id, data):
     return u.to_wrapped_dict(api.scale_cluster, cluster_id, data)
 
@@ -86,7 +86,9 @@ def clusters_update(cluster_id, data):
 @rest.delete('/clusters/<cluster_id>')
 @acl.enforce("data-processing:clusters:delete")
 @v.check_exists(api.get_cluster, 'cluster_id')
-@v.validate(None, v_c.check_cluster_delete)
+@v.validate(v_c_schema.CLUSTER_DELETE_SCHEMA_V2, v_c.check_cluster_delete)
 def clusters_delete(cluster_id):
-    api.terminate_cluster(cluster_id)
+    data = u.request_data()
+    force = data.get('force', False)
+    api.terminate_cluster(cluster_id, force=force)
     return u.render()
