@@ -48,6 +48,7 @@ class Cluster(object):
                       see the docs for details
     default_image_id
     anti_affinity
+    anti_affinity_ratio
     management_private_key
     management_public_key
     user_keypair_id
@@ -64,6 +65,7 @@ class Cluster(object):
     use_autoconfig
     is_public
     is_protected
+    domain_name
     """
 
     def has_proxy_gateway(self):
@@ -87,6 +89,9 @@ class Cluster(object):
         extra = self.extra or {}
         return extra.get('heat_stack_name', self.name)
 
+    def use_designate_feature(self):
+        return CONF.use_designate and self.domain_name
+
 
 class NodeGroup(object):
     """An object representing Node Group.
@@ -152,13 +157,23 @@ class Instance(object):
     management_ip
     volumes
     storage_devices_number
+    dns_hostname
     """
 
     def hostname(self):
         return self.instance_name
 
     def fqdn(self):
-        return self.instance_name + '.' + CONF.node_domain
+        if self._use_designate_feature():
+            return self.dns_hostname
+        else:
+            return self.instance_name + '.' + CONF.node_domain
+
+    def get_ip_or_dns_name(self):
+        if self._use_designate_feature():
+            return self.dns_hostname
+        else:
+            return self.management_ip
 
     def remote(self):
         return remote.get_remote(self)
@@ -173,6 +188,9 @@ class Instance(object):
 
         return mp
 
+    def _use_designate_feature(self):
+        return CONF.use_designate and self.dns_hostname
+
 
 class ClusterTemplate(object):
     """An object representing Cluster Template.
@@ -190,6 +208,7 @@ class ClusterTemplate(object):
     node_groups - list of NodeGroup objects
     is_public
     is_protected
+    domain_name
     """
 
 
@@ -223,6 +242,16 @@ class NodeGroupTemplate(object):
     """
 
 
+class Image(object):
+    """An object representing Image.
+
+    id
+    tags
+    username
+    description
+    """
+
+
 # EDP Objects
 
 class DataSource(object):
@@ -336,3 +365,24 @@ class ClusterEvent(object):
     successful
     step_id
     """
+
+
+class ClusterVerification(object):
+    """An object representing cluster verification
+
+    id
+    cluster_id
+    status
+    checks
+    """
+
+
+class ClusterHealthCheck(object):
+    """An object representing health check
+
+    id
+    verification_id
+    status
+    description
+    name
+    """
