@@ -20,13 +20,17 @@ from requests import auth
 
 from sahara import context
 from sahara.i18n import _
-from sahara.plugins.ambari import decomission_helper as d_helper
+from sahara.plugins.ambari import requests_helper as r_helper
 from sahara.plugins import exceptions as p_exc
 
 
 LOG = logging.getLogger(__name__)
 
 
+class AmbariNotFound(Exception):
+    pass
+
+
 class AmbariClient(object):
     def __init__(self, instance, port="8080", **kwargs):
         kwargs.setdefault("username", "admin")
@@ -74,7 +78,9 @@ class AmbariClient(object):
         return data.get('items', [])
 
     @staticmethod
-    def check_response(resp):
+    def check_response(resp, handle_not_found=False):
+        if handle_not_found and resp.status_code == 404:
+            raise AmbariNotFound()
         resp.raise_for_status()
         if resp.text:
             return jsonutils.loads(resp.text)
@@ -90,6 +96,24 @@ class AmbariClient(object):
                                              "Unexpected response format")
         return body["Requests"]["id"]
 
+    def import_credential(self, cl_name, alias, data):
+        url = self._base_url + "/clusters/%s/credentials/%s" % (cl_name, alias)
+        resp = self.post(url, data=jsonutils.dumps(data))
+        self.check_response(resp)
+
+    def get_credential(self, cl_name, alias):
+        url = self._base_url + "/clusters/%s/credentials/%s" % (cl_name, alias)
+        resp = self.get(url)
+        self.check_response(resp, handle_not_found=True)
+
+    def regenerate_keytabs(self, cl_name):
+        url = (self._base_url +
+               "/clusters/%s?regenerate_keytabs=missing" % cl_name)
+        data = jsonutils.dumps({"Clusters": {"security_type": "KERBEROS"}})
+        resp = self.put(url, data=data)
+        self.check_response(resp)
+        return self.req_id(resp)
+
     def get_registered_hosts(self):
         url = self._base_url + "/hosts"
         resp = self.get(url)
@@ -131,6 +155,23 @@ class AmbariClient(object):
         resp = self.post(url)
         self.check_response(resp)
 
+    def get_config_groups(self, cluster):
+        url = self._base_url + "/clusters/%s/config_groups" % cluster.name
+        resp = self.get(url)
+        return self.check_response(resp)
+
+    def get_detailed_config_group(self, cluster, cfg_id):
+        url = self._base_url + "/clusters/%s/config_groups/%s" % (
+            cluster.name, cfg_id)
+        resp = self.get(url)
+        return self.check_response(resp)
+
+    def remove_config_group(self, cluster, cfg_id):
+        url = self._base_url + "/clusters/%s/config_groups/%s" % (
+            cluster.name, cfg_id)
+        resp = self.delete(url)
+        return self.check_response(resp)
+
     def create_config_group(self, cluster, data):
         url = self._base_url + "/clusters/%s/config_groups" % cluster.name
         resp = self.post(url, data=jsonutils.dumps(data))
@@ -163,14 +204,14 @@ class AmbariClient(object):
 
     def decommission_nodemanagers(self, cluster_name, instances):
         url = self._base_url + "/clusters/%s/requests" % cluster_name
-        data = d_helper.build_nodemanager_decommission_request(cluster_name,
+        data = r_helper.build_nodemanager_decommission_request(cluster_name,
                                                                instances)
         resp = self.post(url, data=jsonutils.dumps(data))
         self.wait_ambari_request(self.req_id(resp), cluster_name)
 
     def decommission_datanodes(self, cluster_name, instances):
         url = self._base_url + "/clusters/%s/requests" % cluster_name
-        data = d_helper.build_datanode_decommission_request(cluster_name,
+        data = r_helper.build_datanode_decommission_request(cluster_name,
                                                             instances)
         resp = self.post(url, data=jsonutils.dumps(data))
         self.wait_ambari_request(self.req_id(resp), cluster_name)
@@ -196,17 +237,29 @@ class AmbariClient(object):
 
     def restart_namenode(self, cluster_name, instance):
         url = self._base_url + "/clusters/%s/requests" % cluster_name
-        data = d_helper.build_namenode_restart_request(cluster_name, instance)
+        data = r_helper.build_namenode_restart_request(cluster_name, instance)
         resp = self.post(url, data=jsonutils.dumps(data))
         self.wait_ambari_request(self.req_id(resp), cluster_name)
 
     def restart_resourcemanager(self, cluster_name, instance):
         url = self._base_url + "/clusters/%s/requests" % cluster_name
-        data = d_helper.build_resourcemanager_restart_request(cluster_name,
+        data = r_helper.build_resourcemanager_restart_request(cluster_name,
                                                               instance)
         resp = self.post(url, data=jsonutils.dumps(data))
         self.wait_ambari_request(self.req_id(resp), cluster_name)
 
+    def restart_service(self, cluster_name, service_name):
+        url = self._base_url + "/clusters/{}/services/{}".format(
+            cluster_name, service_name)
+
+        data = r_helper.build_stop_service_request(service_name)
+        resp = self.put(url, data=jsonutils.dumps(data))
+        self.wait_ambari_request(self.req_id(resp), cluster_name)
+
+        data = r_helper.build_start_service_request(service_name)
+        resp = self.put(url, data=jsonutils.dumps(data))
+        self.wait_ambari_request(self.req_id(resp), cluster_name)
+
     def delete_host(self, cluster_name, instance):
         url = self._base_url + "/clusters/%s/hosts/%s" % (cluster_name,
                                                           instance.fqdn())
@@ -242,6 +295,17 @@ class AmbariClient(object):
         resp = self.put(url, data=jsonutils.dumps(data))
         self.check_response(resp)
 
+    def set_rack_info_for_instance(self, cluster_name, instance, rack_name):
+        url = self._base_url + "/clusters/%s/hosts/%s" % (
+            cluster_name, instance.fqdn())
+        data = {
+            "Hosts": {
+                "rack_info": rack_name
+            }
+        }
+        resp = self.put(url, data=jsonutils.dumps(data))
+        self.check_response(resp)
+
     def get_request_info(self, cluster_name, request_id):
         url = self._base_url + ("/clusters/%s/requests/%s" %
                                 (cluster_name, request_id))
@@ -285,9 +349,11 @@ class AmbariClient(object):
         context.sleep(20)
         while True:
             status = self.check_request_status(cluster_name, request_id)
-            LOG.debug("Task %s in %s state. Completed %.1f%%" % (
-                status["request_context"], status["request_status"],
-                status["progress_percent"]))
+            LOG.debug("Task %(context)s in %(status)s state. "
+                      "Completed %(percent).1f%%",
+                      {'context': status["request_context"],
+                       'status': status["request_status"],
+                       'percent': status["progress_percent"]})
             if status["request_status"] == "COMPLETED":
                 return
             if status["request_status"] in ["IN_PROGRESS", "PENDING"]:
