@@ -23,6 +23,7 @@ from sahara.plugins.ambari import deploy
 from sahara.plugins.ambari import edp_engine
 from sahara.plugins.ambari import health
 from sahara.plugins.ambari import validation
+from sahara.plugins import images
 from sahara.plugins import kerberos
 from sahara.plugins import provisioning as p
 from sahara.plugins import utils as plugin_utils
@@ -151,7 +152,7 @@ class AmbariPluginProvider(p.ProvisioningPluginBase):
                                                  p_common.HBASE_MASTER)
         if hbase_master:
             info[p_common.HBASE_MASTER] = {
-                "Web UI": "http://%s:16010" % hbase_master.get_ip_or_dns_name()
+                "Web UI": "http://%s:60010" % hbase_master.get_ip_or_dns_name()
             }
         falcon = plugin_utils.get_instance(cluster, p_common.FALCON_SERVER)
         if falcon:
@@ -239,8 +240,8 @@ class AmbariPluginProvider(p.ProvisioningPluginBase):
             p_common.DRPC_SERVER: [3772, 3773],
             p_common.FALCON_SERVER: [15000],
             p_common.FLUME_HANDLER: [8020, 41414],
-            p_common.HBASE_MASTER: [16000, 16010],
-            p_common.HBASE_REGIONSERVER: [16020, 16030],
+            p_common.HBASE_MASTER: [60000, 60010],
+            p_common.HBASE_REGIONSERVER: [60020, 60030],
             p_common.HISTORYSERVER: [10020, 19888],
             p_common.HIVE_METASTORE: [9933],
             p_common.HIVE_SERVER: [9999, 10000],
@@ -263,3 +264,28 @@ class AmbariPluginProvider(p.ProvisioningPluginBase):
 
     def get_health_checks(self, cluster):
         return health.get_health_checks(cluster)
+
+    validator = images.SaharaImageValidator.from_yaml(
+        'plugins/ambari/resources/images/image.yaml',
+        resource_roots=['plugins/ambari/resources/images'])
+
+    def get_image_arguments(self, hadoop_version):
+        if hadoop_version != '2.4':
+            return NotImplemented
+        return self.validator.get_argument_list()
+
+    def pack_image(self, hadoop_version, remote,
+                   test_only=False, image_arguments=None):
+        self.validator.validate(remote, test_only=test_only,
+                                image_arguments=image_arguments)
+
+    def validate_images(self, cluster, test_only=False, image_arguments=None):
+        image_arguments = self.get_image_arguments(cluster['hadoop_version'])
+        if not test_only:
+            instances = plugin_utils.get_instances(cluster)
+        else:
+            instances = plugin_utils.get_instances(cluster)[0]
+        for instance in instances:
+            with instance.remote() as r:
+                self.validator.validate(r, test_only=test_only,
+                                        image_arguments=image_arguments)
