@@ -13,11 +13,8 @@
 # under the License.
 
 
-import six
-
 import sahara.plugins.mapr.domain.node_process as np
 import sahara.plugins.mapr.domain.service as s
-import sahara.plugins.mapr.util.commands as cmd
 import sahara.plugins.mapr.util.validation_utils as vu
 
 
@@ -29,7 +26,6 @@ HTTP_FS = np.NodeProcess(
 )
 
 
-@six.add_metaclass(s.Single)
 class HttpFS(s.Service):
     def __init__(self):
         super(HttpFS, self).__init__()
@@ -41,5 +37,4 @@ class HttpFS(s.Service):
         self._validation_rules = [vu.exactly(1, HTTP_FS)]
 
     def post_install(self, cluster_context, instances):
-        instance = cluster_context.get_instance(HTTP_FS)
-        cmd.chown(instance, 'mapr:mapr', self.service_dir(cluster_context))
+        self._set_service_dir_owner(cluster_context, instances)
