@@ -30,11 +30,13 @@ import sahara.plugins.mapr.services.impala.impala as impala
 import sahara.plugins.mapr.services.mapreduce.mapreduce as mr
 import sahara.plugins.mapr.services.mysql.mysql as mysql
 import sahara.plugins.mapr.services.oozie.oozie as oozie
+import sahara.plugins.mapr.services.sentry.sentry as sentry
 import sahara.plugins.mapr.services.spark.spark as spark
 import sahara.plugins.mapr.services.sqoop.sqoop2 as sqoop
 import sahara.plugins.mapr.services.yarn.yarn as yarn
+import sahara.plugins.mapr.util.event_log as el
 import sahara.plugins.mapr.util.general as g
-from sahara.plugins.mapr.util import service_utils as su
+import sahara.plugins.mapr.util.password_utils as pu
 import sahara.plugins.mapr.util.validation_utils as vu
 import sahara.plugins.provisioning as p
 import sahara.utils.files as files
@@ -49,7 +51,7 @@ HUE = np.NodeProcess(
 )
 
 HUE_LIVY = np.NodeProcess(
-    name="hue-livy",
+    name="livy",
     ui_name="Hue Livy",
     package="mapr-hue-livy",
     open_ports=[8998]
@@ -74,7 +76,7 @@ class Hue(s.Service):
         self._name = 'hue'
         self._ui_name = 'Hue'
         self._node_processes = [HUE]
-        self._ui_info = [('HUE', HUE, 'http://%s:8888')]
+        self._ui_info = None
         self._validation_rules = [
             vu.exactly(1, HUE),
             vu.on_same_node(HUE, httpfs.HTTP_FS),
@@ -82,6 +84,13 @@ class Hue(s.Service):
         ]
         self._priority = 2
 
+    def get_ui_info(self, cluster_context):
+        # Hue uses credentials of the administrative user (PAM auth)
+        return [('HUE', HUE, {s.SERVICE_UI: 'http://%s:8888',
+                              'Username': 'mapr',
+                              'Password': pu.get_mapr_password(cluster_context
+                                                               .cluster)})]
+
     def get_configs(self):
         return [Hue.THRIFT_VERSION]
 
@@ -114,16 +123,9 @@ class Hue(s.Service):
 
         return [hue_ini, hue_sh]
 
-    def _get_packages(self, cluster_context, node_processes):
-        result = []
-
-        result += self.dependencies
-        result += [(np.package, self.version) for np in [HUE]]
-        return result
-
-    def _get_hue_ini_props(self, context):
-        db_instance = mysql.MySQL.get_db_instance(context)
-        is_yarn = context.cluster_mode == 'yarn'
+    def _get_hue_ini_props(self, cluster_context):
+        db_instance = mysql.MySQL.get_db_instance(cluster_context)
+        is_yarn = cluster_context.cluster_mode == 'yarn'
         hue_specs = mysql.MySQL.HUE_SPECS
         rdbms_specs = mysql.MySQL.RDBMS_SPECS
 
@@ -135,51 +137,65 @@ class Hue(s.Service):
             'rdbms_name': rdbms_specs.db_name,
             'rdbms_user': rdbms_specs.user,
             'rdbms_password': rdbms_specs.password,
-            'resource_manager_uri': context.resource_manager_uri,
+            'resource_manager_uri': cluster_context.resource_manager_uri,
             'yarn_mode': is_yarn,
-            'rm_host': context.get_instance_ip(yarn.RESOURCE_MANAGER),
-            'webhdfs_url': context.get_instance_ip(httpfs.HTTP_FS),
-            'jt_host': context.get_instance_ip(mr.JOB_TRACKER),
-            'oozie_host': context.get_instance_ip(oozie.OOZIE),
-            'sqoop_host': context.get_instance_ip(sqoop.SQOOP_2_SERVER),
-            'impala_host': context.get_instance_ip(impala.IMPALA_STATE_STORE),
-            'zk_hosts_with_port': context.get_zookeeper_nodes_ip_with_port(),
+            'rm_host': cluster_context.get_instance_ip(yarn.RESOURCE_MANAGER),
+            'webhdfs_url': cluster_context.get_instance_ip(httpfs.HTTP_FS),
+            'jt_host': cluster_context.get_instance_ip(mr.JOB_TRACKER),
+            'oozie_host': cluster_context.get_instance_ip(oozie.OOZIE),
+            'sqoop_host': cluster_context.get_instance_ip(
+                sqoop.SQOOP_2_SERVER),
+            'impala_host': cluster_context.get_instance_ip(
+                impala.IMPALA_STATE_STORE),
+            'zk_hosts_with_port':
+                cluster_context.get_zookeeper_nodes_ip_with_port(),
             'secret_key': self._generate_secret_key()
         }
 
-        hive_host = context.get_instance(hive.HIVE_SERVER_2)
+        hive_host = cluster_context.get_instance(hive.HIVE_SERVER_2)
         if hive_host:
-            hive_service = context.get_service(hive.HIVE_SERVER_2)
+            hive_service = cluster_context.get_service(hive.HIVE_SERVER_2)
             result.update({
                 'hive_host': hive_host.internal_ip,
                 'hive_version': hive_service.version,
-                'hive_conf_dir': hive_service.conf_dir(context),
+                'hive_conf_dir': hive_service.conf_dir(cluster_context),
             })
 
-        hbase_host = context.get_instance(hbase.HBASE_THRIFT)
+        hbase_host = cluster_context.get_instance(hbase.HBASE_THRIFT)
         if hbase_host:
-            hbase_service = context.get_service(hbase.HBASE_THRIFT)
+            hbase_service = cluster_context.get_service(hbase.HBASE_THRIFT)
             result.update({
                 'hbase_host': hbase_host.internal_ip,
-                'hbase_conf_dir': hbase_service.conf_dir(context),
+                'hbase_conf_dir': hbase_service.conf_dir(cluster_context),
             })
 
-        livy_host = context.get_instance(HUE_LIVY)
-        spark_instance = context.get_instance(
-            spark.SPARK_HISTORY_SERVER)
-        if livy_host and spark_instance:
+        livy_host = cluster_context.get_instance(HUE_LIVY)
+        if livy_host:
             result.update({
                 'livy_host': livy_host.internal_ip
             })
 
+        sentry_host = cluster_context.get_instance(sentry.SENTRY)
+        if sentry_host:
+            ui_name = sentry.Sentry().ui_name
+            sentry_version = cluster_context.get_chosen_service_version(
+                ui_name)
+            sentry_service = cluster_context. \
+                _find_service_instance(ui_name, sentry_version)
+            result.update({
+                'sentry_host': sentry_host.internal_ip,
+                'sentry_conf': sentry_service.conf_dir(cluster_context)
+            })
+
         return result
 
     def post_install(self, cluster_context, instances):
         hue_instance = cluster_context.get_instance(HUE)
 
-        def migrate_database(remote, context):
-            hue_service = context.get_service(HUE)
-            hue_home = '/opt/mapr/hue/hue-%s' % hue_service.version
+        @el.provision_event(name=_("Migrating Hue database"),
+                            instance=hue_instance)
+        def migrate_database(remote, cluster_context):
+            hue_home = self.home_dir(cluster_context)
             cmd = '%(activate)s && %(syncdb)s && %(migrate)s'
             args = {
                 'activate': 'source %s/build/env/bin/activate' % hue_home,
@@ -188,31 +204,29 @@ class Hue(s.Service):
             }
             remote.execute_command(cmd % args, run_as_root=True, timeout=600)
 
-        def set_owner(remote):
-            remote.execute_command('chown -R mapr:mapr /opt/mapr/hue',
-                                   run_as_root=True)
+        def hue_syncdb_workround(remote):
+            cmd = 'printf "/opt/mapr/lib\n$JAVA_HOME/jre/lib/amd64/server\n"' \
+                  ' | tee /etc/ld.so.conf.d/mapr-hue.conf && ldconfig'
+            remote.execute_command(cmd, run_as_root=True)
 
-        if hue_instance:
-            with hue_instance.remote() as r:
-                LOG.debug("Executing Hue database migration")
-                migrate_database(r, cluster_context)
-                LOG.debug("Changing Hue home dir owner")
-                set_owner(r)
-            self._copy_hive_configs(cluster_context, hue_instance)
-            self._install_jt_plugin(cluster_context, hue_instance)
+        def centos7_workaround(remote):
+            cmd = 'ln -s /lib64/libsasl2.so.3.0.0 /lib64/libsasl2.so.2' \
+                  ' && rpm -ivh --nodeps http://yum.mariadb.org/5.5.49/' \
+                  'rhel7-amd64/rpms/MariaDB-5.5.49-centos7-x86_64-compat.rpm'
+            remote.execute_command(cmd, run_as_root=True,
+                                   raise_when_error=False)
 
-        hue_livy_instance = cluster_context.get_instance(HUE_LIVY)
-        if hue_livy_instance:
-            with hue_livy_instance.remote() as r:
-                LOG.debug("Changing Hue home dir owner")
-                set_owner(r)
-
-    def _set_hue_sh_chmod(self, cluster_context):
-        cmd = 'chmod 777 %s' % (self.home_dir(cluster_context) + '/bin/hue.sh')
-        hue_instance = cluster_context.get_instance(HUE)
-        if hue_instance:
-            with hue_instance.remote() as r:
-                r.execute_command(cmd, run_as_root=True)
+        with hue_instance.remote() as r:
+            LOG.debug("Executing Hue database migration")
+            # workaround for centos7
+            if cluster_context.distro_version.split('.')[0] == '7':
+                centos7_workaround(r)
+            # temporary workaround to prevent failure of db migrate on mapr 5.2
+            hue_syncdb_workround(r)
+            migrate_database(r, cluster_context)
+        self._copy_hive_configs(cluster_context, hue_instance)
+        self._install_jt_plugin(cluster_context, hue_instance)
+        self._set_service_dir_owner(cluster_context, instances)
 
     def _copy_hive_configs(self, cluster_context, hue_instance):
         hive_server = cluster_context.get_instance(hive.HIVE_SERVER_2)
@@ -225,42 +239,22 @@ class Hue(s.Service):
 
     def update(self, cluster_context, instances=None):
         if self._should_restart(cluster_context, instances):
-            hue_instance = cluster_context.get_instance(HUE)
-            self.restart([hue_instance])
+            self.restart(instances)
 
     def post_start(self, cluster_context, instances):
-        self._install_livy(cluster_context, instances=instances)
         self.update(cluster_context, instances=instances)
 
-    def restart(self, instances):
-        for node_process in [HUE]:
-            filtered_instances = su.filter_by_node_process(instances,
-                                                           node_process)
-            if filtered_instances:
-                node_process.restart(filtered_instances)
-
-    # need to be installed after cldb start
-    def _install_livy(self, cluster_context, instances):
-        hue_livy_instance = cluster_context.get_instance(HUE_LIVY)
-        spark_instance = cluster_context.get_instance(
-            spark.SPARK_HISTORY_SERVER)
-        if hue_livy_instance and spark_instance:
-            with hue_livy_instance.remote() as r:
-                cmd = cluster_context.distro.create_install_cmd(
-                    [(HUE_LIVY.package, self.version)])
-                r.execute_command(cmd, run_as_root=True,
-                                  timeout=s._INSTALL_PACKAGES_TIMEOUT)
-
-    def _should_restart(self, c_context, instances):
+    def _should_restart(self, cluster_context, instances):
         app_services = [
             impala.Impala(),
             hive.Hive(),
             hbase.HBase(),
             sqoop.Sqoop2(),
-            spark.Spark(),
+            spark.SparkOnYarn(),
         ]
-        instances = [c_context.filter_instances(instances, service=service)
-                     for service in app_services]
+        instances = [
+            cluster_context.filter_instances(instances, service=service)
+            for service in app_services]
         return bool(g.unique_list(itertools.chain(*instances)))
 
     def jt_plugin_path(self, cluster_context):
@@ -272,6 +266,8 @@ class Hue(s.Service):
         }
         return path % args
 
+    @el.provision_event(name="Install Hue Job Tracker plugin",
+                        instance_reference=2)
     def _install_jt_plugin(self, cluster_context, hue_instance):
         LOG.debug("Copying Hue JobTracker plugin")
         job_trackers = cluster_context.get_instances(mr.JOB_TRACKER)
@@ -318,14 +314,52 @@ class HueV390(Hue):
         self._node_processes = [HUE, HUE_LIVY]
         self._validation_rules.append(vu.at_most(1, HUE_LIVY))
 
-    def _get_hue_ini_props(self, context):
-        result = super(HueV390, self)._get_hue_ini_props(context)
-        ssl_cert_file = 'cert.pem'
-        ssl_key_file = 'hue_private_keystore.pem'
-        result.update({
-            'ssl_cert': '%(home)s/%(file)s' % {'home': self.home_dir(context),
-                                               'file': ssl_cert_file},
-            'ssl_key': '%(home)s/%(file)s' % {'home': self.home_dir(context),
-                                              'file': ssl_key_file}
-        })
-        return result
+
+class HueV310(Hue):
+    def __init__(self):
+        super(HueV310, self).__init__()
+        self._version = "3.10.0"
+        self._node_processes = [HUE]
+        self._validation_rules.append(vu.at_most(1, HUE_LIVY))
+
+
+class HueLivyV310(s.Service):
+    def __init__(self):
+        super(HueLivyV310, self).__init__()
+        self._name = 'hue-livy'
+        self._ui_name = 'Livy'
+        self._version = "3.10.0"
+        self._node_processes = [HUE_LIVY]
+        self._validation_rules = [vu.at_most(1, HUE_LIVY),
+                                  vu.depends_on(HueV310(), self),
+                                  vu.depends_on(spark.SparkOnYarnV201(), self),
+                                  vu.on_same_node(HUE_LIVY, spark.SPARK_SLAVE)]
+
+    def get_config_files(self, cluster_context, configs, instance=None):
+        livy_conf_template = 'plugins/mapr/services/hue/' \
+                             'resources/livy_conf_%s.template'
+        livy_conf = bcf.TemplateFile("livy.conf")
+        livy_conf.parse(files.get_file_text(livy_conf_template % self.version))
+        livy_conf.remote_path = self.home_dir(cluster_context) + '/conf'
+
+        livy_sh_template = 'plugins/mapr/services/hue/' \
+                           'resources/livy_sh_%s.template'
+        livy_sh = bcf.TemplateFile("livy-env.sh")
+        livy_sh.remote_path = self.home_dir(cluster_context) + '/conf'
+        livy_sh.parse(files.get_file_text(livy_sh_template % self.version))
+        livy_sh.add_property('hadoop_version', cluster_context.hadoop_version)
+        livy_sh.add_property('spark_version', spark.SparkOnYarnV201().version)
+        livy_sh.mode = 777
+
+        hue_instances = cluster_context.get_instances(HUE)
+        for instance in hue_instances:
+            if instance not in cluster_context.changed_instances():
+                cluster_context.should_be_restarted[self] += [instance]
+
+        return [livy_sh, livy_conf]
+
+    def post_install(self, cluster_context, instances):
+        self._set_service_dir_owner(cluster_context, instances)
+
+    def post_start(self, cluster_context, instances):
+        self.restart(instances)
