@@ -17,7 +17,6 @@ from oslo_log import log as logging
 
 from sahara import context
 from sahara.i18n import _
-from sahara.i18n import _LI
 import sahara.plugins.mapr.domain.configuration_file as bcf
 import sahara.plugins.mapr.domain.node_process as np
 import sahara.plugins.mapr.domain.service as s
@@ -113,7 +112,7 @@ class MapRFS(s.Service):
             for instance in file_servers:
                 tg.spawn('init-mfs-%s' % instance.id,
                          self._init_mfs_instance, instance)
-        LOG.info(_LI('MapR FS successfully initialized'))
+        LOG.info('MapR FS successfully initialized')
 
     @el.provision_event(instance_reference=1)
     def _init_mfs_instance(self, instance):
