@@ -14,16 +14,15 @@
 # limitations under the License.
 
 from oslo_config import cfg
-from oslo_log import log as logging
+import six
 
+from sahara.plugins import provisioning as p
 from sahara.plugins.vanilla.hadoop2 import config_helper as c_helper
 from sahara.utils import xmlutils as x
 
 CONF = cfg.CONF
 CONF.import_opt("enable_data_locality", "sahara.topology.topology_helper")
 
-LOG = logging.getLogger(__name__)
-
 CORE_DEFAULT = x.load_hadoop_xml_defaults(
     'plugins/vanilla/v2_7_1/resources/core-default.xml')
 
@@ -69,7 +68,6 @@ ENV_CONFS = {
     }
 }
 
-
 # Initialise plugin Hadoop configurations
 PLUGIN_XML_CONFIGS = c_helper.init_xml_configs(XML_CONFS)
 PLUGIN_ENV_CONFIGS = c_helper.init_env_configs(ENV_CONFS)
@@ -80,9 +78,39 @@ def _init_all_configs():
     configs.extend(PLUGIN_XML_CONFIGS)
     configs.extend(PLUGIN_ENV_CONFIGS)
     configs.extend(c_helper.PLUGIN_GENERAL_CONFIGS)
+    configs.extend(_get_spark_configs())
+    configs.extend(_get_zookeeper_configs())
     return configs
 
 
+def _get_spark_configs():
+    spark_configs = []
+    for service, config_items in six.iteritems(c_helper.SPARK_CONFS):
+        for item in config_items['OPTIONS']:
+            cfg = p.Config(name=item["name"],
+                           description=item["description"],
+                           default_value=item["default"],
+                           applicable_target=service,
+                           scope="cluster", is_optional=True,
+                           priority=item["priority"])
+            spark_configs.append(cfg)
+    return spark_configs
+
+
+def _get_zookeeper_configs():
+    zk_configs = []
+    for service, config_items in six.iteritems(c_helper.ZOOKEEPER_CONFS):
+        for item in config_items['OPTIONS']:
+            cfg = p.Config(name=item["name"],
+                           description=item["description"],
+                           default_value=item["default"],
+                           applicable_target=service,
+                           scope="cluster", is_optional=True,
+                           priority=item["priority"])
+            zk_configs.append(cfg)
+    return zk_configs
+
+
 PLUGIN_CONFIGS = _init_all_configs()
 
 
