@@ -83,15 +83,10 @@ def _check_cluster_create(data):
 
     neutron_net_id = _get_cluster_field(data, 'neutron_management_network')
     if neutron_net_id:
-        if not CONF.use_neutron:
-            raise ex.InvalidReferenceException(
-                _("'neutron_management_network' field can't be used "
-                  "with 'use_neutron=False'"))
         b.check_network_exists(neutron_net_id)
     else:
-        if CONF.use_neutron:
-            raise ex.NotFoundException('neutron_management_network',
-                                       _("'%s' field is not found"))
+        raise ex.NotFoundException('neutron_management_network',
+                                   _("'%s' field is not found"))
 
 
 def _get_cluster_field(cluster, field):
