@@ -55,7 +55,7 @@ def get_swift_configs():
     configs = x.load_hadoop_xml_defaults('swift/resources/conf-template.xml')
     for conf in configs:
         if conf['name'] == HADOOP_SWIFT_AUTH_URL:
-            conf['value'] = su.retrieve_auth_url() + "tokens/"
+            conf['value'] = su.retrieve_auth_url() + "auth/tokens/"
         if conf['name'] == HADOOP_SWIFT_TENANT:
             conf['value'] = retrieve_tenant()
         if CONF.os_region_name and conf['name'] == HADOOP_SWIFT_REGION:
