@@ -353,7 +353,7 @@ class SaharaMigrationsCheckers(object):
 
     def _check_007(self, engine, data):
         t = db_utils.get_table(engine, 'clusters')
-        res = engine.execute(t.select(), id='123').first()
+        res = engine.execute(t.select().where(t.c.id == '123')).first()
         self.assertEqual('magic', res['status_description'])
         engine.execute(t.delete())
 
@@ -543,6 +543,89 @@ class SaharaMigrationsCheckers(object):
     def _check_028(self, engine, data):
         self.assertColumnExists(engine, 'instances', 'storage_devices_number')
 
+    def _pre_upgrade_029(self, engine):
+        t = db_utils.get_table(engine, 'node_group_templates')
+        engine.execute(t.insert(), id='123', name='first', plugin_name='plg',
+                       hadoop_version='1', flavor_id='1', volumes_per_node=0,
+                       is_default=True, is_protected=False)
+
+        engine.execute(t.insert(), id='124', name='second', plugin_name='plg',
+                       hadoop_version='1', flavor_id='1', volumes_per_node=0,
+                       is_default=False, is_protected=False)
+
+        t = db_utils.get_table(engine, 'cluster_templates')
+        engine.execute(t.insert(), id='123', name='name', plugin_name='plg',
+                       hadoop_version='1', is_default=True, is_protected=False)
+
+        engine.execute(t.insert(), id='124', name='name', plugin_name='plg',
+                       hadoop_version='1', is_default=False,
+                       is_protected=False)
+
+    def _check_029(self, engine, data):
+        t = db_utils.get_table(engine, 'node_group_templates')
+        res = engine.execute(t.select().where(t.c.id == '123')).first()
+        self.assertTrue(res['is_protected'])
+
+        res = engine.execute(t.select().where(t.c.id == '124')).first()
+        self.assertFalse(res['is_protected'])
+        engine.execute(t.delete())
+
+        t = db_utils.get_table(engine, 'cluster_templates')
+        res = engine.execute(t.select().where(t.c.id == '123')).first()
+        self.assertTrue(res['is_protected'])
+
+        res = engine.execute(t.select().where(t.c.id == '124')).first()
+        self.assertFalse(res['is_protected'])
+        engine.execute(t.delete())
+
+    def _check_030(self, engine, data):
+        health_check_columns = [
+            'status',
+            'name',
+            'description',
+            'id',
+            'verification_id',
+            'created_at',
+            'updated_at'
+        ]
+
+        verification_columns = [
+            'status',
+            'id',
+            'cluster_id',
+            'created_at',
+            'updated_at'
+        ]
+
+        self.assertColumnCount(engine, 'cluster_verifications',
+                               verification_columns)
+        self.assertColumnsExist(engine, 'cluster_verifications',
+                                verification_columns)
+
+        self.assertColumnCount(engine, 'cluster_health_checks',
+                               health_check_columns)
+        self.assertColumnsExist(engine, 'cluster_health_checks',
+                                health_check_columns)
+
+    def _check_031(self, engine, data):
+        plugins_data_columns = [
+            'name',
+            'id',
+            'tenant_id',
+            'version_labels',
+            'plugin_labels',
+            'updated_at',
+            'created_at'
+        ]
+
+        self.assertColumnCount(engine, 'plugin_data',
+                               plugins_data_columns)
+        self.assertColumnsExist(engine, 'plugin_data',
+                                plugins_data_columns)
+
+    def _check_033(self, engine, data):
+        self.assertColumnExists(engine, 'clusters', 'anti_affinity_ratio')
+
 
 class TestMigrationsMySQL(SaharaMigrationsCheckers,
                           base.BaseWalkMigrationTestCase,
