@@ -24,16 +24,25 @@ class TestPlugin(test_base.SaharaTestCase):
 
     def test_job_types(self):
         self.assertEqual({
-            '2.2': [
-                'Hive', 'Java', 'MapReduce', 'MapReduce.Streaming',
-                'Pig', 'Shell'],
             '2.3': [
                 'Hive', 'Java', 'MapReduce', 'MapReduce.Streaming',
-                'Pig', 'Shell']
+                'Pig', 'Shell', 'Spark'],
+            '2.4': [
+                'Hive', 'Java', 'MapReduce', 'MapReduce.Streaming',
+                'Pig', 'Shell', 'Spark'],
+            '2.5': [
+                'Hive', 'Java', 'MapReduce', 'MapReduce.Streaming',
+                'Pig', 'Shell', 'Spark'],
         }, self.plugin.get_edp_job_types())
 
         self.assertEqual({
             '2.3': [
                 'Hive', 'Java', 'MapReduce', 'MapReduce.Streaming',
-                'Pig', 'Shell'],
+                'Pig', 'Shell', 'Spark'],
         }, self.plugin.get_edp_job_types(versions=['2.3']))
+
+        self.assertEqual({
+            '2.4': [
+                'Hive', 'Java', 'MapReduce', 'MapReduce.Streaming',
+                'Pig', 'Shell', 'Spark'],
+        }, self.plugin.get_edp_job_types(versions=['2.4']))
