@@ -58,7 +58,7 @@ def get_concrete_cluster():
                "KS_INDEXER": {}, "SPARK_ON_YARN": {}, "SENTRY": {}, "YARN": {},
                "ZOOKEEPER": {}, "OOZIE": {}, "HBASE": {}, "IMPALA": {}}
     # cluster is immutable, a work around
-    dict.__setitem__(cluster, "cluster_config", configs)
+    dict.__setitem__(cluster, "cluster_configs", configs)
 
     # add fake remotes to instances
     instances = [i for ng in cluster.node_groups for i in ng.instances]
@@ -144,7 +144,7 @@ class TestPluginUtils(b.SaharaTestCase):
     def test_configure_swift(self, log_cfg):
 
         cluster = get_concrete_cluster()
-        cluster.cluster_config['general']['Enable Swift'] = True
+        cluster.cluster_configs['general']['Enable Swift'] = True
         instances = [i for ng in cluster.node_groups for i in ng.instances]
 
         self.plug_utils.configure_swift(cluster)
@@ -174,7 +174,7 @@ class TestPluginUtils(b.SaharaTestCase):
         db_password = 'a8f2939f-ff9f-4659-a333-abc012ee9b2d'
         uuid4.return_value = db_password
         create_db_script = files.get_file_text(
-            'plugins/cdh/{version}/resources/create_hive_db.sql'
+            'plugins/cdh/db_resources/create_hive_db.sql'
                                 .format(version=self.version))
         create_db_script = create_db_script % db_password
 
@@ -250,7 +250,8 @@ class TestPluginUtils(b.SaharaTestCase):
             calls = [mock.call('ls /var/lib/oozie/ext-2.2',
                                raise_when_error=False),
                      mock.call("curl -L -o '/var/lib/oozie/extjs.zip'"
-                               " http://dev.sencha.com/deploy/ext-2.2.zip",
+                               " http://tarballs.openstack.org/sahara/dist/"
+                               "common-artifacts/ext-2.2.zip",
                                run_as_root=True),
                      mock.call('unzip /var/lib/oozie/extjs.zip'
                                ' -d /var/lib/oozie',
@@ -279,6 +280,15 @@ class TestPluginUtils(b.SaharaTestCase):
                 2, {'manager': manager}]
         plugin_option_poll.assert_called_once_with(*call)
 
+    def test_get_config_value(self):
+        cluster = get_concrete_cluster()
+        dfs_replication = self.plug_utils.get_config_value(
+            'HDFS', 'dfs_replication', cluster)
+        self.assertEqual(1, dfs_replication)
+        dfs_replication_default = self.plug_utils.get_config_value(
+            'HDFS', 'dfs_replication')
+        self.assertEqual(3, dfs_replication_default)
+
 
 class TestPluginUtilsHigherThanV5(TestPluginUtils):
 
@@ -295,7 +305,7 @@ class TestPluginUtilsHigherThanV5(TestPluginUtils):
         db_password = 'a8f2939f-ff9f-4659-a333-abc012ee9b2d'
         uuid4.return_value = db_password
         create_db_script = files.get_file_text(
-            'plugins/cdh/{version}/resources/create_sentry_db.sql'
+            'plugins/cdh/db_resources/create_sentry_db.sql'
                                 .format(version=self.version))
         create_db_script = create_db_script % db_password
 
