@@ -15,24 +15,23 @@
 
 import mock
 
-from sahara import exceptions as ex
 from sahara.plugins import base as pb
-from sahara.plugins.cdh.v5_9_0 import edp_engine
+from sahara.plugins.cdh.v5_11_0 import edp_engine
 from sahara.plugins import exceptions as pl_ex
 from sahara.tests.unit import base as sahara_base
 from sahara.tests.unit.plugins.cdh import utils as c_u
 from sahara.utils import edp
 
 
-def get_cluster(version='5.9.0'):
+def get_cluster(version='5.11.0'):
     cluster = c_u.get_fake_cluster(plugin_name='CDH', hadoop_version=version)
     return cluster
 
 
-class EdpEngineTestV590(sahara_base.SaharaTestCase):
+class EdpEngineTestV5110(sahara_base.SaharaTestCase):
 
     def setUp(self):
-        super(EdpEngineTestV590, self).setUp()
+        super(EdpEngineTestV5110, self).setUp()
         pb.setup_plugins()
 
     def test_get_hdfs_user(self):
@@ -105,10 +104,10 @@ class EdpEngineTestV590(sahara_base.SaharaTestCase):
         actual_config = edp_engine.EdpOozieEngine.get_possible_job_config(
             edp.JOB_TYPE_HIVE)
         get_possible_hive_config_from.assert_called_once_with(
-            'plugins/cdh/v5_9_0/resources/hive-site.xml')
+            'plugins/cdh/v5_11_0/resources/hive-site.xml')
         self.assertEqual(expected_config, actual_config)
 
-    @mock.patch('sahara.plugins.cdh.v5_9_0.edp_engine.EdpOozieEngine')
+    @mock.patch('sahara.plugins.cdh.v5_11_0.edp_engine.EdpOozieEngine')
     def test_get_possible_job_config_java(self, BaseCDHEdpOozieEngine):
         expected_config = {'job_config': {}}
         BaseCDHEdpOozieEngine.get_possible_job_config.return_value = (
@@ -129,7 +128,7 @@ class EdpEngineTestV590(sahara_base.SaharaTestCase):
         actual_config = edp_engine.EdpOozieEngine.get_possible_job_config(
             edp.JOB_TYPE_MAPREDUCE)
         get_possible_mapreduce_config_from.assert_called_once_with(
-            'plugins/cdh/v5_9_0/resources/mapred-site.xml')
+            'plugins/cdh/v5_11_0/resources/mapred-site.xml')
         self.assertEqual(expected_config, actual_config)
 
     @mock.patch(
@@ -142,7 +141,7 @@ class EdpEngineTestV590(sahara_base.SaharaTestCase):
         actual_config = edp_engine.EdpOozieEngine.get_possible_job_config(
             edp.JOB_TYPE_MAPREDUCE_STREAMING)
         get_possible_mapreduce_config_from.assert_called_once_with(
-            'plugins/cdh/v5_9_0/resources/mapred-site.xml')
+            'plugins/cdh/v5_11_0/resources/mapred-site.xml')
         self.assertEqual(expected_config, actual_config)
 
     @mock.patch(
@@ -154,10 +153,10 @@ class EdpEngineTestV590(sahara_base.SaharaTestCase):
         actual_config = edp_engine.EdpOozieEngine.get_possible_job_config(
             edp.JOB_TYPE_PIG)
         get_possible_pig_config_from.assert_called_once_with(
-            'plugins/cdh/v5_9_0/resources/mapred-site.xml')
+            'plugins/cdh/v5_11_0/resources/mapred-site.xml')
         self.assertEqual(expected_config, actual_config)
 
-    @mock.patch('sahara.plugins.cdh.v5_9_0.edp_engine.EdpOozieEngine')
+    @mock.patch('sahara.plugins.cdh.v5_11_0.edp_engine.EdpOozieEngine')
     def test_get_possible_job_config_shell(self, BaseCDHEdpOozieEngine):
         expected_config = {'job_config': {}}
         BaseCDHEdpOozieEngine.get_possible_job_config.return_value = (
@@ -167,34 +166,3 @@ class EdpEngineTestV590(sahara_base.SaharaTestCase):
         BaseCDHEdpOozieEngine.get_possible_job_config.assert_called_once_with(
             edp.JOB_TYPE_SHELL)
         self.assertEqual(expected_config, actual_config)
-
-    @mock.patch('sahara.plugins.utils.get_config_value_or_default')
-    @mock.patch('sahara.plugins.utils.get_instance')
-    @mock.patch('sahara.service.edp.spark.engine.'
-                'SparkJobEngine.validate_job_execution')
-    def test_spark_engine_validate_job_execution(self,
-                                                 validate_job_execution,
-                                                 get_instance,
-                                                 get_config_value_or_default):
-        # version unsupported
-        cluster = get_cluster(version='5.4.0')
-        eng = edp_engine.EdpSparkEngine(cluster)
-        self.assertRaises(ex.InvalidDataException,
-                          eng.validate_job_execution, cluster,
-                          mock.Mock(), mock.Mock())
-
-        # none yarn history server
-        cluster = get_cluster()
-        eng = edp_engine.EdpSparkEngine(cluster)
-        self.assertRaises(pl_ex.InvalidComponentCountException,
-                          eng.validate_job_execution, cluster,
-                          mock.Mock(), mock.Mock())
-
-        # valid
-        cluster = get_cluster()
-        yarn_history_node_group = mock.Mock()
-        yarn_history_node_group.node_processes = ['SPARK_YARN_HISTORY_SERVER']
-        yarn_history_node_group.count = 1
-        list.append(cluster.node_groups, yarn_history_node_group)
-        eng = edp_engine.EdpSparkEngine(cluster)
-        eng.validate_job_execution(cluster, mock.Mock(), mock.Mock())
