@@ -13,10 +13,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import uuid
 
 import mock
-import six
+from oslo_utils import uuidutils
 
 from sahara import conductor as cond
 from sahara.utils import edp
@@ -64,7 +63,7 @@ def create_job_binary(id, type):
     return binary
 
 
-def create_cluster(plugin_name='vanilla', hadoop_version='2.6.0'):
+def create_cluster(plugin_name='vanilla', hadoop_version='2.7.1'):
     cluster = mock.Mock()
     cluster.plugin_name = plugin_name
     cluster.hadoop_version = hadoop_version
@@ -89,10 +88,14 @@ def create_data_source(url, name=None, id=None):
 
 def _create_job_exec(job_id, type, configs=None, info=None):
     j_exec = mock.Mock()
-    j_exec.id = six.text_type(uuid.uuid4())
+    j_exec.id = uuidutils.generate_uuid()
     j_exec.job_id = job_id
     j_exec.job_configs = configs
     j_exec.info = info
+    j_exec.input_id = 4
+    j_exec.output_id = 5
+    j_exec.engine_job_id = None
+    j_exec.data_source_urls = {}
     if not j_exec.job_configs:
         j_exec.job_configs = {}
     if edp.compare_job_type(type, edp.JOB_TYPE_JAVA):
