@@ -13,15 +13,16 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import uuid
+import time
 
 import mock
-import six
+from oslo_utils import timeutils
+from oslo_utils import uuidutils
 import testtools
 
 from sahara import exceptions as ex
 from sahara import main
-from sahara.service import api
+from sahara.service.api import v10 as api
 from sahara.service.validations.edp import job_execution as je
 from sahara.service.validations.edp import job_execution_schema as je_schema
 from sahara.tests.unit.service.validation import utils as u
@@ -52,8 +53,8 @@ class TestJobExecCreateValidation(u.ValidationTestCase):
         get_job.return_value = mock.Mock(
             type=edp.JOB_TYPE_MAPREDUCE_STREAMING, libs=[], interface=[])
 
-        ds1_id = six.text_type(uuid.uuid4())
-        ds2_id = six.text_type(uuid.uuid4())
+        ds1_id = uuidutils.generate_uuid()
+        ds2_id = uuidutils.generate_uuid()
 
         data_sources = {
             ds1_id: mock.Mock(type="swift", url="http://swift/test"),
@@ -65,16 +66,17 @@ class TestJobExecCreateValidation(u.ValidationTestCase):
         ng = tu.make_ng_dict('master', 42, ['oozie'], 1,
                              instances=[tu.make_inst_dict('id', 'name')])
         get_cluster.return_value = tu.create_cluster("cluster", "tenant1",
-                                                     "vanilla", "2.6.0", [ng])
+                                                     "vanilla", "2.7.1", [ng])
 
         self._assert_create_object_validation(
             data={
-                "cluster_id": six.text_type(uuid.uuid4()),
+                "cluster_id": uuidutils.generate_uuid(),
                 "input_id": ds1_id,
                 "output_id": ds2_id,
                 "job_configs": {"configs": {},
                                 "params": {},
-                                "args": []}
+                                "args": [],
+                                "job_execution_info": {}}
             },
             bad_req_i=(1, "INVALID_DATA",
                           "MapReduce.Streaming job "
@@ -83,7 +85,7 @@ class TestJobExecCreateValidation(u.ValidationTestCase):
 
         self._assert_create_object_validation(
             data={
-                "cluster_id": six.text_type(uuid.uuid4()),
+                "cluster_id": uuidutils.generate_uuid(),
                 "input_id": ds1_id,
                 "output_id": ds2_id,
                 "job_configs": {
@@ -91,6 +93,7 @@ class TestJobExecCreateValidation(u.ValidationTestCase):
                         "edp.streaming.mapper": "/bin/cat",
                         "edp.streaming.reducer": "/usr/bin/wc"},
                     "params": {},
+                    "job_execution_info": {},
                     "args": []}
             })
 
@@ -101,8 +104,8 @@ class TestJobExecCreateValidation(u.ValidationTestCase):
         get_job.return_value = mock.Mock(
             type=edp.JOB_TYPE_MAPREDUCE_STREAMING, libs=[], interface=[])
 
-        ds1_id = six.text_type(uuid.uuid4())
-        ds2_id = six.text_type(uuid.uuid4())
+        ds1_id = uuidutils.generate_uuid()
+        ds2_id = uuidutils.generate_uuid()
 
         data_sources = {
             ds1_id: mock.Mock(type="swift", url="http://swift/test"),
@@ -114,11 +117,11 @@ class TestJobExecCreateValidation(u.ValidationTestCase):
         ng = tu.make_ng_dict('master', 42, ['oozie'], 1,
                              instances=[tu.make_inst_dict('id', 'name')])
         get_cluster.return_value = tu.create_cluster("cluster", "tenant1",
-                                                     "vanilla", "2.6.0", [ng])
+                                                     "vanilla", "2.7.1", [ng])
 
         self._assert_create_object_validation(
             data={
-                "cluster_id": six.text_type(uuid.uuid4()),
+                "cluster_id": uuidutils.generate_uuid(),
                 "input_id": ds1_id,
                 "output_id": ds2_id,
                 "job_configs": {
@@ -126,6 +129,7 @@ class TestJobExecCreateValidation(u.ValidationTestCase):
                         "edp.streaming.mapper": "/bin/cat",
                         "edp.streaming.reducer": "/usr/bin/wc"},
                     "params": {},
+                    "job_execution_info": {},
                     "args": []}
             })
 
@@ -136,7 +140,7 @@ class TestJobExecCreateValidation(u.ValidationTestCase):
 
         self._assert_create_object_validation(
             data={
-                "cluster_id": six.text_type(uuid.uuid4()),
+                "cluster_id": uuidutils.generate_uuid(),
                 "input_id": ds1_id,
                 "output_id": ds2_id,
                 "job_configs": {
@@ -144,6 +148,7 @@ class TestJobExecCreateValidation(u.ValidationTestCase):
                         "edp.streaming.mapper": "/bin/cat",
                         "edp.streaming.reducer": "/usr/bin/wc"},
                     "params": {},
+                    "job_execution_info": {},
                     "args": []}
             },
             bad_req_i=(1, "INVALID_DATA", err_msg))
@@ -157,13 +162,13 @@ class TestJobExecCreateValidation(u.ValidationTestCase):
         ng = tu.make_ng_dict('master', 42, ['namenode'], 1,
                              instances=[tu.make_inst_dict('id', 'name')])
         get_cluster.return_value = tu.create_cluster("cluster", "tenant1",
-                                                     "vanilla", "2.6.0", [ng])
+                                                     "vanilla", "2.7.1", [ng])
 
         self._assert_create_object_validation(
             data={
-                "cluster_id": six.text_type(uuid.uuid4()),
-                "input_id": six.text_type(uuid.uuid4()),
-                "output_id": six.text_type(uuid.uuid4())
+                "cluster_id": uuidutils.generate_uuid(),
+                "input_id": uuidutils.generate_uuid(),
+                "output_id": uuidutils.generate_uuid()
             },
             bad_req_i=(1, "INVALID_COMPONENT_COUNT",
                        "Hadoop cluster should contain 1 oozie component(s). "
@@ -183,11 +188,11 @@ class TestJobExecCreateValidation(u.ValidationTestCase):
         ng = tu.make_ng_dict('master', 42, [], 1,
                              instances=[tu.make_inst_dict('id', 'name')])
         get_cluster.return_value = tu.create_cluster("cluster", "tenant1",
-                                                     "spark", "1.0.0", [ng])
+                                                     "spark", "1.3.1", [ng])
 
         # Everything is okay, spark cluster supports EDP by default
         # because cluster requires a master and slaves >= 1
-        wrap_it(data={"cluster_id": six.text_type(uuid.uuid4()),
+        wrap_it(data={"cluster_id": uuidutils.generate_uuid(),
                       "job_configs": {
                           "configs": {
                               "edp.java.main_class": "org.me.class"}}})
@@ -200,14 +205,15 @@ class TestJobExecCreateValidation(u.ValidationTestCase):
         ng = tu.make_ng_dict('master', 42, ['namenode', 'oozie'], 1,
                              instances=[tu.make_inst_dict('id', 'name')])
         cluster_get.return_value = tu.create_cluster("cluster", "tenant1",
-                                                     "vanilla", "2.6.0", [ng])
+                                                     "vanilla", "2.7.1", [ng])
 
         self._assert_create_object_validation(
             data={
-                "cluster_id": six.text_type(uuid.uuid4()),
+                "cluster_id": uuidutils.generate_uuid(),
                 "job_configs": {"configs": {},
                                 "params": {},
-                                "args": []}
+                                "args": [],
+                                "job_execution_info": {}}
             },
             bad_req_i=(1, "INVALID_DATA",
                           "%s job must "
@@ -215,11 +221,26 @@ class TestJobExecCreateValidation(u.ValidationTestCase):
 
         self._assert_create_object_validation(
             data={
-                "cluster_id": six.text_type(uuid.uuid4()),
+                "cluster_id": uuidutils.generate_uuid(),
+                "job_configs": {
+                    "configs": {
+                        "edp.java.main_class": ""},
+                    "params": {},
+                    "args": [],
+                    "job_execution_info": {}}
+            },
+            bad_req_i=(1, "INVALID_DATA",
+                          "%s job must "
+                          "specify edp.java.main_class" % edp.JOB_TYPE_JAVA))
+
+        self._assert_create_object_validation(
+            data={
+                "cluster_id": uuidutils.generate_uuid(),
                 "job_configs": {
                     "configs": {
                         "edp.java.main_class": "org.me.myclass"},
                     "params": {},
+                    "job_execution_info": {},
                     "args": []}
             })
 
@@ -231,14 +252,15 @@ class TestJobExecCreateValidation(u.ValidationTestCase):
         ng = tu.make_ng_dict('master', 42, ['namenode'], 1,
                              instances=[tu.make_inst_dict('id', 'name')])
         cluster_get.return_value = tu.create_cluster("cluster", "tenant1",
-                                                     "spark", "1.0.0", [ng])
+                                                     "spark", "1.3.1", [ng])
 
         self._assert_create_object_validation(
             data={
-                "cluster_id": six.text_type(uuid.uuid4()),
+                "cluster_id": uuidutils.generate_uuid(),
                 "job_configs": {"configs": {},
                                 "params": {},
-                                "args": []}
+                                "args": [],
+                                "job_execution_info": {}}
             },
             bad_req_i=(1, "INVALID_DATA",
                           "%s job must "
@@ -246,14 +268,39 @@ class TestJobExecCreateValidation(u.ValidationTestCase):
 
         self._assert_create_object_validation(
             data={
-                "cluster_id": six.text_type(uuid.uuid4()),
+                "cluster_id": uuidutils.generate_uuid(),
+                "job_configs": {
+                    "configs": {
+                        "edp.java.main_class": ""},
+                    "params": {},
+                    "args": [],
+                    "job_execution_info": {}}
+            },
+            bad_req_i=(1, "INVALID_DATA",
+                          "%s job must "
+                          "specify edp.java.main_class" % edp.JOB_TYPE_SPARK))
+
+        self._assert_create_object_validation(
+            data={
+                "cluster_id": uuidutils.generate_uuid(),
                 "job_configs": {
                     "configs": {
                         "edp.java.main_class": "org.me.myclass"},
                     "params": {},
+                    "job_execution_info": {},
                     "args": []}
             })
 
+    @mock.patch('oslo_utils.timeutils.utcnow')
+    def test_invalid_start_time_in_job_execution_info(self, now_get):
+        configs = {"start": "2015-07-21 14:32:52"}
+        now = time.strptime("2015-07-22 14:39:14", "%Y-%m-%d %H:%M:%S")
+        now = timeutils.datetime.datetime.fromtimestamp(time.mktime(now))
+        now_get.return_value = now
+
+        with testtools.ExpectedException(ex.InvalidJobExecutionInfoException):
+            je.check_scheduled_job_execution_info(configs)
+
 
 class TestJobExecUpdateValidation(u.ValidationTestCase):
 
@@ -265,7 +312,10 @@ class TestJobExecUpdateValidation(u.ValidationTestCase):
     def test_job_execution_update_types(self):
         data = {
             'is_public': False,
-            'is_protected': False
+            'is_protected': False,
+            'info': {
+                'status': 'suspend'
+            }
         }
         self._assert_types(data)
 
@@ -273,7 +323,10 @@ class TestJobExecUpdateValidation(u.ValidationTestCase):
         self._assert_create_object_validation(
             data={
                 'is_public': False,
-                'is_protected': False
+                'is_protected': False,
+                'info': {
+                    'status': 'suspend'
+                }
             }
         )
 
@@ -286,14 +339,14 @@ class TestJobExecUpdateValidation(u.ValidationTestCase):
         # job execution can't be updated if it's marked as protected
         with testtools.ExpectedException(ex.UpdateFailedException):
             try:
-                je.check_job_execution_update(job_exec, {'is_public': True})
+                je.check_job_execution_update(job_exec, {'job_configs': {}})
             except ex.UpdateFailedException as e:
                 self.assert_protected_resource_exception(e)
                 raise e
         # job execution can be updated because is_protected flag was
         # set to False
         je.check_job_execution_update(
-            job_exec, {'is_protected': False, 'is_public': True})
+            job_exec, {'is_protected': False, 'job_configs': {}})
 
     @mock.patch('sahara.conductor.api.LocalApi.job_execution_get')
     def test_public_je_cancel_delete_from_another_tenant(self, get_je_p):
