@@ -13,11 +13,11 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import uuid
 
 import mock
+from oslo_utils import uuidutils
 
-from sahara.service import api
+from sahara.service.api import v10 as api
 from sahara.service.validations import cluster_template_schema as ct_schema
 from sahara.service.validations import cluster_templates as ct
 from sahara.tests.unit.service.validation import utils as u
@@ -156,7 +156,8 @@ class TestClusterTemplateCreateValidation(u.ValidationTestCase):
                         "name": "test",
                         'count': 3
                     }
-                ]
+                ],
+                'domain_name': 'domain.org.'
             },
 
         )
@@ -210,7 +211,7 @@ class TestClusterTemplateCreateValidation(u.ValidationTestCase):
                 'name': 'testname',
                 'plugin_name': 'fake',
                 'hadoop_version': '0.1',
-                'default_image_id': str(uuid.uuid4()),
+                'default_image_id': uuidutils.generate_uuid(),
                 'cluster_configs': {
                     "service_1": {
                         "config_1": "value_1"
@@ -226,7 +227,8 @@ class TestClusterTemplateCreateValidation(u.ValidationTestCase):
                 ],
                 'anti_affinity': ['datanode'],
                 'description': 'my template',
-                'neutron_management_network': str(uuid.uuid4())
+                'neutron_management_network': uuidutils.generate_uuid(),
+                'domain_name': 'domain.org.'
             })
 
     @mock.patch("sahara.service.validations.base.check_network_exists")
@@ -244,7 +246,8 @@ class TestClusterTemplateCreateValidation(u.ValidationTestCase):
                 'node_groups': None,
                 'anti_affinity': None,
                 'description': None,
-                'neutron_management_network': None
+                'neutron_management_network': None,
+                'domain_name': None
             })
 
     def test_cluster_template_create_v_plugin_name_exists(self):
