@@ -16,7 +16,7 @@
 import mock
 
 from sahara.tests.unit import base
-from sahara.utils.openstack import nova as nova_client
+from sahara.utils.openstack import images as sahara_images
 
 
 class FakeImage(object):
@@ -29,8 +29,8 @@ class FakeImage(object):
 class TestImages(base.SaharaTestCase):
     def setUp(self):
         super(TestImages, self).setUp()
-        self.override_config('auth_uri', 'https://127.0.0.1:8080/v3/',
-                             'keystone_authtoken')
+        self.override_config('auth_url', 'https://127.0.0.1:8080/v3/',
+                             'trustee')
 
     @mock.patch('sahara.utils.openstack.base.url_for', return_value='')
     def test_list_registered_images(self, url_for_mock):
@@ -39,38 +39,54 @@ class TestImages(base.SaharaTestCase):
             FakeImage('baz', [], 'test'),
             FakeImage('spam', [], "")]
 
-        with mock.patch('novaclient.v2.images.ImageManager.list',
-                        return_value=some_images):
-            nova = nova_client.client()
+        with mock.patch(
+                'sahara.utils.openstack.images.SaharaImageManager.list',
+                return_value=some_images):
+            manager = sahara_images.image_manager()
 
-            images = nova.images.list_registered()
+            images = manager.list_registered()
             self.assertEqual(2, len(images))
 
-            images = nova.images.list_registered(name='foo')
+            images = manager.list_registered(name='foo')
             self.assertEqual(1, len(images))
             self.assertEqual('foo', images[0].name)
             self.assertEqual('test', images[0].username)
 
-            images = nova.images.list_registered(name='eggs')
+            images = manager.list_registered(name='eggs')
             self.assertEqual(0, len(images))
 
-            images = nova.images.list_registered(tags=['bar'])
+            images = manager.list_registered(tags=['bar'])
             self.assertEqual(1, len(images))
             self.assertEqual('foo', images[0].name)
 
-            images = nova.images.list_registered(tags=['bar', 'eggs'])
+            images = manager.list_registered(tags=['bar', 'eggs'])
             self.assertEqual(0, len(images))
 
-    @mock.patch('novaclient.v2.images.ImageManager.set_meta')
-    def test_set_description(self, set_meta):
+    @mock.patch('sahara.utils.openstack.images.SaharaImageManager.set_meta')
+    def test_set_image_info(self, set_meta):
         with mock.patch('sahara.utils.openstack.base.url_for'):
-            nova = nova_client.client()
-            nova.images.set_description('id', 'ubuntu')
+            manager = sahara_images.image_manager()
+            manager.set_image_info('id', 'ubuntu')
             self.assertEqual(
                 ('id', {'_sahara_username': 'ubuntu'}), set_meta.call_args[0])
 
-            nova.images.set_description('id', 'ubuntu', 'descr')
+            manager.set_image_info('id', 'ubuntu', 'descr')
             self.assertEqual(
                 ('id', {'_sahara_description': 'descr',
                         '_sahara_username': 'ubuntu'}),
                 set_meta.call_args[0])
+
+    @mock.patch('sahara.utils.openstack.images.SaharaImageManager.get')
+    @mock.patch('sahara.utils.openstack.images.SaharaImageManager.delete_meta')
+    def test_unset_image_info(self, delete_meta, get_image):
+            manager = sahara_images.image_manager()
+            image = mock.MagicMock()
+            image.tags = ['fake', 'fake_2.0']
+            image.username = 'ubuntu'
+            image.description = 'some description'
+            get_image.return_value = image
+            manager.unset_image_info('id')
+            self.assertEqual(
+                ('id', ['_sahara_tag_fake', '_sahara_tag_fake_2.0',
+                        '_sahara_description', '_sahara_username']),
+                delete_meta.call_args[0])
