@@ -33,7 +33,7 @@ class TestEscapeQuotes(testtools.TestCase):
 class TestGetOsDistrib(testtools.TestCase):
     @mock.patch('sahara.utils.ssh_remote._execute_command',
                 return_value=[1, 'Ubuntu'])
-    @mock.patch('sahara.utils.ssh_remote.__get_python_to_execute',
+    @mock.patch('sahara.utils.ssh_remote._get_python_to_execute',
                 return_value='python3')
     def test_get_os_distrib(self, python, p_execute_command):
         d = ssh_remote._get_os_distrib()
