@@ -15,20 +15,22 @@
 
 import socket
 
-from keystoneclient import exceptions as keystone_ex
+from keystoneauth1 import exceptions as keystone_ex
+from oslo_config import cfg
 from oslo_log import log as logging
 from six.moves.urllib import parse
 
 from sahara import conductor as c
 from sahara import context
 from sahara import exceptions as e
-from sahara.i18n import _LI
 from sahara.utils.notification import sender
 from sahara.utils.openstack import base as auth_base
 
 conductor = c.API
 LOG = logging.getLogger(__name__)
 
+CONF = cfg.CONF
+
 # cluster status
 CLUSTER_STATUS_VALIDATING = "Validating"
 CLUSTER_STATUS_INFRAUPDATING = "InfraUpdating"
@@ -93,8 +95,8 @@ def change_cluster_status(cluster, status, status_description=None):
     cluster = conductor.cluster_update(ctx, cluster, update_dict)
     conductor.cluster_provision_progress_update(ctx, cluster.id)
 
-    LOG.info(_LI("Cluster status has been changed. New status="
-                 "{status}").format(status=cluster.status))
+    LOG.info("Cluster status has been changed. New status="
+             "{status}".format(status=cluster.status))
 
     sender.status_notify(cluster.id, cluster.name, cluster.status,
                          "update")
@@ -132,22 +134,53 @@ def clean_cluster_from_empty_ng(cluster):
             conductor.node_group_remove(ctx, ng)
 
 
-def generate_etc_hosts(cluster):
-    hosts = "127.0.0.1 localhost\n"
+def etc_hosts_entry_for_service(service):
+    result = ""
+    try:
+        hostname = parse.urlparse(
+            auth_base.url_for(service_type=service,
+                              endpoint_type="publicURL")).hostname
+    except keystone_ex.EndpointNotFound:
+        LOG.debug("Endpoint not found for service: '{}'".format(service))
+        return result
+    try:
+        result = "%s %s\n" % (socket.gethostbyname(hostname), hostname)
+    except socket.gaierror:
+        LOG.warning("Failed to resolve hostname of service: '{}'"
+                    .format(service))
+        result = "# Failed to resolve {} during deployment\n".format(hostname)
+    return result
+
+
+def _etc_hosts_for_services(hosts):
+    # add alias for keystone and swift
+    for service in ["identity", "object-store"]:
+        hosts += etc_hosts_entry_for_service(service)
+    return hosts
+
+
+def _etc_hosts_for_instances(hosts, cluster):
     for node_group in cluster.node_groups:
         for instance in node_group.instances:
             hosts += "%s %s %s\n" % (instance.internal_ip,
                                      instance.fqdn(),
                                      instance.hostname())
-    # add alias for keystone and swift
-    for service in ["identity", "object-store"]:
-        try:
-            hostname = parse.urlparse(
-                auth_base.url_for(service_type=service,
-                                  endpoint_type="publicURL")).hostname
-        except keystone_ex.EndpointNotFound:
-            LOG.debug("Endpoint not found for service: \"%s\"", service)
-            continue
-        hosts += "%s %s\n" % (socket.gethostbyname(hostname), hostname)
-
     return hosts
+
+
+def generate_etc_hosts(cluster):
+    hosts = "127.0.0.1 localhost\n"
+    if not cluster.use_designate_feature():
+        hosts = _etc_hosts_for_instances(hosts, cluster)
+    hosts = _etc_hosts_for_services(hosts)
+    return hosts
+
+
+def generate_resolv_conf_diff(curr_resolv_conf):
+    # returns string that contains nameservers
+    # which are lacked in the 'curr_resolve_conf'
+    resolv_conf = ""
+    for ns in CONF.nameservers:
+        if ns not in curr_resolv_conf:
+            resolv_conf += "nameserver {}\n".format(ns)
+    return resolv_conf
