@@ -19,8 +19,9 @@ from oslo_config import cfg
 from sahara import context
 from sahara import exceptions as ex
 from sahara.i18n import _
+from sahara.service import sessions
 from sahara.utils.openstack import base
-
+from sahara.utils.openstack import keystone
 
 opts = [
     cfg.BoolOpt('api_insecure',
@@ -43,14 +44,13 @@ CONF.register_opts(opts, group=heat_group)
 
 
 def client():
-    ctx = context.current()
+    ctx = context.ctx()
+    session = sessions.cache().get_heat_session()
     heat_url = base.url_for(ctx.service_catalog, 'orchestration',
                             endpoint_type=CONF.heat.endpoint_type)
-    return heat_client.Client('1', heat_url, token=ctx.auth_token,
-                              cert_file=CONF.heat.ca_file,
-                              insecure=CONF.heat.api_insecure,
-                              username=ctx.username,
-                              include_pass=True)
+    return heat_client.Client(
+        '1', endpoint=heat_url, session=session, auth=keystone.auth(),
+        region_name=CONF.os_region_name)
 
 
 def get_stack(stack_name, raise_on_missing=True):
@@ -66,6 +66,39 @@ def get_stack(stack_name, raise_on_missing=True):
                                _('Failed to find stack %(stack)s'))
 
 
+def delete_stack(cluster):
+    stack_name = cluster.stack_name
+    base.execute_with_retries(client().stacks.delete, stack_name)
+    stack = get_stack(stack_name, raise_on_missing=False)
+    while stack is not None:
+        # Valid states: IN_PROGRESS, empty and COMPLETE
+        if stack.status in ['IN_PROGRESS', '', 'COMPLETE']:
+            context.sleep(5)
+        else:
+            raise ex.HeatStackException(
+                message=_(
+                    "Cannot delete heat stack {name}, reason: "
+                    "stack status: {status}, status reason: {reason}").format(
+                    name=stack_name, status=stack.status,
+                    reason=stack.stack_status_reason))
+        stack = get_stack(stack_name, raise_on_missing=False)
+
+
+def abandon_stack(cluster):
+    '''Put stack in deleting state if not already, then abandon it.'''
+    heat_client = client()
+    stack_name = cluster.stack_name
+    base.execute_with_retries(heat_client.stacks.delete, stack_name)
+    # TODO(jfreud): sleep between calls?
+    base.execute_with_retries(heat_client.stacks.abandon, stack_name)
+
+
+def get_stack_outputs(cluster):
+    stack = get_stack(cluster.stack_name)
+    stack.get()
+    return stack.outputs
+
+
 def _verify_completion(stack, is_update=False, last_update_time=None):
     # NOTE: expected empty status because status of stack
     # maybe is not set in heat database
@@ -77,16 +110,12 @@ def _verify_completion(stack, is_update=False, last_update_time=None):
     return True
 
 
-def wait_stack_completion(stack, is_update=False, last_updated_time=None):
-    base.execute_with_retries(stack.get)
+def wait_stack_completion(cluster, is_update=False, last_updated_time=None):
+    stack_name = cluster.stack_name
+    stack = get_stack(stack_name)
     while not _verify_completion(stack, is_update, last_updated_time):
         context.sleep(1)
-        base.execute_with_retries(stack.get)
+        stack = get_stack(stack_name)
 
     if stack.status != 'COMPLETE':
         raise ex.HeatStackException(stack.stack_status_reason)
-
-
-def get_resource(stack, resource):
-    return base.execute_with_retries(
-        client().resources.get, stack, resource)
