@@ -19,13 +19,10 @@ import sys
 
 from eventlet.green import subprocess
 from eventlet import timeout as e_timeout
-from oslo_log import log as logging
 
 from sahara import context
 from sahara import exceptions
 
-LOG = logging.getLogger(__name__)
-
 
 def _get_sub_executable():
     return '%s/_sahara-subprocess' % os.path.dirname(sys.argv[0])
@@ -58,7 +55,7 @@ def run_in_subprocess(proc, func, args=None, kwargs=None, interactive=False):
 
             return result['output']
     finally:
-        # NOTE(dmitryme): in openstack/common/processutils.py it
+        # NOTE(dmitryme): in oslo.concurrency's file processutils.py it
         # is suggested to sleep a little between calls to multiprocessing.
         # That should allow it make some necessary cleanup
         context.sleep(0)
